.. _sec_gallery:

=======
Gallery
=======

This page includes a number of examples that illustrate various features
of demography descriptions using `demes`, as well as some well-known and
more complicated models of human history.

.. _sec_zigzag_example:

Zigzag model
------------

.. literalinclude:: ../examples/zigzag.yml
   :language: yaml
   :linenos:

.. _sec_im_example:

Isolation-with-migration
------------------------

Two populations.


.. _sec_ooa_example:

Gutenkunst et al. (2009) Out-of-Africa expansion
------------------------------------------------

.. literalinclude:: ../examples/gutenkunst_ooa.yml
   :language: yaml
   :linenos:

.. _sec_denisova_example:

Jacobs et al. (2019) Denisovan admixture
----------------------------------------

.. literalinclude:: ../examples/jacobs_papuans.yml
   :language: yaml
   :linenos:
